@@ -2,4 +2,5 @@ from PyHyperScattering import Fitting
 from PyHyperScattering import HDR
 from PyHyperScattering import RSoXS
 from PyHyperScattering import IntegrationUtils
-from PyHyperScattering import Nexus
\ No newline at end of file
+#from PyHyperScattering import Nexus empty module as of 0.0.6-dev69
+from PyHyperScattering import FileIO
\ No newline at end of file
